@@ -6,17 +6,11 @@ isort:skip_file
 # flake8: NOQA: E402
 
 # -- stdlib imports ------------------------------------------------------------
-from sunpy_sphinx_theme.conf import *
-import sunpy.data.sample  # isort:skip
-from sunpy import __version__
-import sunpy
-from sphinx_gallery.sorting import ExampleTitleSortKey
-from sphinx_gallery.sorting import ExplicitOrder
-import ruamel.yaml as yaml
 import os
 import sys
 import datetime
 from pkg_resources import get_distribution, DistributionNotFound
+from packaging.version import Version
 
 # -- Check for dependencies ----------------------------------------------------
 
@@ -43,9 +37,16 @@ if on_rtd:
     os.environ['HOME'] = '/home/docs/'
     os.environ['LANG'] = 'C'
     os.environ['LC_ALL'] = 'C'
+    os.environ['HIDE_PARFIVE_PROGESS'] = 'True'
 
 # -- Non stdlib imports --------------------------------------------------------
 
+import ruamel.yaml as yaml  # NOQA
+from sphinx_gallery.sorting import ExplicitOrder  # NOQA
+from sphinx_gallery.sorting import ExampleTitleSortKey  # NOQA
+
+import sunpy  # NOQA
+from sunpy import __version__  # NOQA
 
 # -- Project information -------------------------------------------------------
 
@@ -55,7 +56,8 @@ copyright = '{}, {}'.format(datetime.datetime.now().year, author)
 
 # The full version, including alpha/beta/rc tags
 release = __version__
-is_development = '.dev' in __version__
+sunpy_version = Version(__version__)
+is_release = not(sunpy_version.is_prerelease or sunpy_version.is_devrelease)
 
 # -- SunPy Sample Data and Config ----------------------------------------------
 
@@ -63,11 +65,12 @@ is_development = '.dev' in __version__
 # in the CI, especially RTD.
 ori_level = sunpy.log.level
 sunpy.log.setLevel("DEBUG")
+import sunpy.data.sample  # NOQA
 sunpy.log.setLevel(ori_level)
 
 # For the linkcheck
 linkcheck_ignore = [r"https://doi.org/\d+",
-                    r"https://riot.im/\d+",
+                    r"https://element.io/\d+",
                     r"https://github.com/\d+",
                     r"https://docs.sunpy.org/\d+"]
 linkcheck_anchors = False
@@ -91,33 +94,24 @@ suppress_warnings = ['app.add_directive', ]
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
 # ones.
 extensions = [
-    'sphinx.ext.autodoc',
-    'sphinx.ext.intersphinx',
-    'sphinx.ext.todo',
-    'sphinx.ext.coverage',
-    'sphinx.ext.inheritance_diagram',
-    'sphinx.ext.viewcode',
-    'sphinx.ext.napoleon',
-    'sphinx.ext.doctest',
-    'sphinx.ext.mathjax',
+    'matplotlib.sphinxext.plot_directive',
     'sphinx_automodapi.automodapi',
     'sphinx_automodapi.smart_resolver',
     'sphinx_gallery.gen_gallery',
+    'sphinx.ext.autodoc',
+    'sphinx.ext.coverage',
+    'sphinx.ext.doctest',
+    'sphinx.ext.inheritance_diagram',
+    'sphinx.ext.intersphinx',
+    'sphinx.ext.mathjax',
+    'sphinx.ext.napoleon',
+    'sphinx.ext.todo',
+    'sphinx.ext.viewcode',
     'sunpy.util.sphinx.doctest',
-    'matplotlib.sphinxext.plot_directive',
-    'sunpy.util.sphinx.minigallery',
     'sunpy.util.sphinx.generate',
     'sunpy.util.sphinx.changelog',
 ]
 
-if on_rtd:
-    rtd_version = os.environ.get('READTHEDOCS_VERSION', None)
-    stable = (rtd_version == 'stable') or (rtd_version[0] == 'v')
-    if stable:
-        # Stable versions have a manually rendered changelog, so remove the
-        # changelog extension
-        extensions.remove('sunpy.util.sphinx.changelog')
-
 # Add any paths that contain templates here, relative to this directory.
 # templates_path = ['_templates']
 
@@ -132,6 +126,9 @@ html_extra_path = ['robots.txt']
 
 exclude_patterns = ['_build', 'Thumbs.db', '.DS_Store']
 
+if is_release:
+    exclude_patterns.append('dev_guide/contents/*')
+
 # The suffix(es) of source filenames.
 # You can specify multiple suffix as a list of string:
 source_suffix = '.rst'
@@ -174,7 +171,7 @@ intersphinx_mapping = {
     "pandas": ("https://pandas.pydata.org/pandas-docs/stable/", None),
     "skimage": ("https://scikit-image.org/docs/stable/", None),
     "drms": ("https://docs.sunpy.org/projects/drms/en/stable/", None),
-    "parfive": ("https://parfive.readthedocs.io/en/latest/", None),
+    "parfive": ("https://parfive.readthedocs.io/en/stable/", None),
     "reproject": ("https://reproject.readthedocs.io/en/stable/", None),
     "aiapy": ("https://aiapy.readthedocs.io/en/stable/", None),
 }
@@ -184,6 +181,7 @@ intersphinx_mapping = {
 # The theme to use for HTML and HTML Help pages.  See the documentation for
 # a list of builtin themes.
 
+from sunpy_sphinx_theme.conf import *  # NOQA
 
 # Add any paths that contain custom static files (such as style sheets) here,
 # relative to this directory. They are copied after the builtin static files,
@@ -225,18 +223,20 @@ sphinx_gallery_conf = {
     # Comes from the theme.
     "default_thumb_file": os.path.join(html_static_path[0], "img", "sunpy_icon_128x128.png"),
     'abort_on_example_error': False,
-    'plot_gallery': True,
+    'plot_gallery': 'True',
     'remove_config_comments': True,
-    'doc_module': ('sunpy')
+    'doc_module': ('sunpy'),
+    'only_warn_on_example_error': True,
 }
 
 # -- Stability Page ------------------------------------------------------------
 
-with open('./dev_guide/sunpy_stability.yaml', 'r') as estability:
+with open('./code_ref/sunpy_stability.yaml', 'r') as estability:
     sunpy_modules = yaml.load(estability.read(), Loader=yaml.Loader)
 
 html_context = {
-    'sunpy_modules': sunpy_modules
+    'sunpy_modules': sunpy_modules,
+    'is_development': not is_release,
 }
 
 
@@ -247,19 +247,22 @@ def rstjinja(app, docname, source):
     # Make sure we're outputting HTML
     if app.builder.format != 'html':
         return
-    src = source[0]
-    if "Current status" in src[:20]:
+    files_to_render = ["code_ref/stability", "dev_guide/index"]
+    if docname in files_to_render:
+        print(f"Jinja rendering {docname}")
         rendered = app.builder.templates.render_string(
-            src, app.config.html_context
+            source[0], app.config.html_context
         )
         source[0] = rendered
 
-# -- Sphinx setup --------------------------------------------------------------
+# JSOC email os env
+os.environ["JSOC_EMAIL"] = "jsoc@cadair.com"
 
+# -- Sphinx setup --------------------------------------------------------------
 
 def setup(app):
     # Generate the stability page
     app.connect("source-read", rstjinja)
-
-    # The theme conf provides a fix for circle ci redirections
-    fix_circleci(app)
+    if is_release:
+        from sunpy.util.sphinx.changelog import DummyChangelog
+        app.add_directive('changelog', DummyChangelog, override=True)
