@@ -17,9 +17,11 @@ import parfive
 
 from astropy.table import Table
 
+from sunpy import config
 from sunpy.net import attr, vso
-from sunpy.net.base_client import BaseClient, BaseQueryResponse
+from sunpy.net.base_client import BaseClient, QueryResponseColumn, QueryResponseRow, QueryResponseTable
 from sunpy.util.datatype_factory_base import BasicRegistrationFactory, NoMatchError
+from sunpy.util.decorators import deprecated
 from sunpy.util.parfive_helpers import Downloader, Results
 from sunpy.util.util import get_width
 
@@ -43,24 +45,41 @@ class UnifiedResponse(Sequence):
         """
         Parameters
         ----------
-        results : `sunpy.net.base_client.BaseQueryResponse`
+        results : `sunpy.net.base_client.QueryResponseTable`
             One or more QueryResponse objects.
         """
         self._list = []
         self._numfile = 0
         for result in results:
-            if not isinstance(result, BaseQueryResponse):
+            if isinstance(result, QueryResponseRow):
+                result = result.as_table()
+
+            if isinstance(result, QueryResponseColumn):
+                result = result.as_table()
+
+            if not isinstance(result, QueryResponseTable):
                 raise TypeError(
-                    f"{type(result)} is not derived from sunpy.net.base_client.BaseQueryResponse")
+                    f"{type(result)} is not derived from sunpy.net.base_client.QueryResponseTable")
 
             self._list.append(result)
-            self._numfile = len(result)
+            self._numfile += len(result)
 
     def __len__(self):
         return len(self._list)
 
-    def __iter__(self):
-        return self.responses
+    def _getitem_string(self, aslice):
+        ret = []
+        for res in self._list:
+            clientname = res.client.__class__.__name__
+            if aslice.lower() == clientname.lower().split('client')[0]:
+                ret.append(res)
+
+        if len(ret) == 1:
+            ret = ret[0]
+        elif len(ret) == 0:
+            raise IndexError(f"{aslice} is not a valid key, valid keys are: {','.join(self.keys())}")
+
+        return ret
 
     def __getitem__(self, aslice):
         """
@@ -69,14 +88,13 @@ class UnifiedResponse(Sequence):
         The first index is to the client and the second index is the records
         returned from those clients.
         """
-        # Just a single int as a slice, we are just indexing client.
-        # Convert it to a slice so we still return a list.
-        if isinstance(aslice, int):
-            aslice = slice(aslice, aslice + 1)
-
-        if isinstance(aslice, slice):
+        if isinstance(aslice, (int, slice)):
             ret = self._list[aslice]
 
+        # using the client's name for indexing the responses.
+        elif isinstance(aslice, str):
+            ret = self._getitem_string(aslice)
+
         # Make sure we only have a length two slice.
         elif isinstance(aslice, tuple):
             if len(aslice) > 2:
@@ -84,43 +102,56 @@ class UnifiedResponse(Sequence):
                                  "be sliced with one or two indices.")
 
             # Indexing both client and records, but only for one client.
-            if isinstance(aslice[0], int):
-                client_resp = self._list[aslice[0]]
-                ret = [client_resp[aslice[1]]]
-
-            # Indexing both client and records for multiple clients.
+            if isinstance(aslice[0], str):
+                intermediate = self._getitem_string(aslice[0])
             else:
                 intermediate = self._list[aslice[0]]
+
+            if isinstance(intermediate, list):
                 ret = []
                 for client_resp in intermediate:
                     ret.append(client_resp[aslice[1]])
+            else:
+                ret = intermediate[aslice[1]]
 
         else:
-            raise IndexError("UnifiedResponse objects must be sliced with integers.")
+            raise IndexError("UnifiedResponse objects must be sliced with integers or strings.")
+
+        if isinstance(ret, (QueryResponseTable, QueryResponseColumn, QueryResponseRow)):
+            return ret
 
         return UnifiedResponse(*ret)
 
-    def get_response(self, i):
+    @deprecated("2.1", "The same behaviour can now be obtained by indexing the object directly")
+    def get_response(self, i):  # pragma: no cover
         """
         Get the actual response rather than another UnifiedResponse object.
         """
         return self._list[i]
 
+    @deprecated("2.1", alternative="path_format_keys")
     def response_block_properties(self):
-        """
-        A set of class attributes on all the response blocks.
+        return self.path_format_keys()
 
-        Returns
-        -------
-        s : list
-            List of strings, containing attribute names in the response blocks.
+    def path_format_keys(self):
         """
-        s = self.get_response(0).response_block_properties()
-        for i in range(1, len(self)):
-            s.intersection(self.get_response(i).response_block_properties())
+        Returns all the names that can be used to format filenames.
+
+        Only the keys which can be used to format all results from all
+        responses contained in this `~.UnifiedResponse` are returned. Each
+        individual response might have more keys available.
+
+        Each one corresponds to a single column in the table, and the format
+        syntax should match the dtype of that column, i.e. for a ``Time``
+        object or a ``Quantity``.
+        """
+        s = self[0].path_format_keys()
+        for table in self[1:]:
+            s = s.intersection(table.path_format_keys())
         return s
 
     @property
+    @deprecated("2.1", "All objects contained in the sequence are now Table objects")
     def tables(self):
         """
         Returns a list of `astropy.table.Table` for all responses present in a specific
@@ -136,23 +167,37 @@ class UnifiedResponse(Sequence):
             `sunpy.net.dataretriever.client.QueryResponse`, `sunpy.net.vso.QueryResponse` or
             `sunpy.net.jsoc.JSOCClient`.
         """
-        tables = []
-        for block in self.responses:
-            tables.append(block.build_table())
-        return tables
+        return list(self)
 
     @property
-    def responses(self):
+    @deprecated("2.1", "The same behaviour can be obtained by iterating over the object directly")
+    def responses(self):  # pragma: no cover
         """
         A generator of all the `sunpy.net.dataretriever.client.QueryResponse`
         objects contained in the `~sunpy.net.fido_factory.UnifiedResponse`
         object.
         """
-        for i in range(len(self)):
-            yield self.get_response(i)
+        for table in self:
+            yield table
+
+    def keys(self):
+        """
+        Names of the contained responses.
+
+        One name may map to more than one response.
+        """
+        ret = []
+        for res in self._list:
+            clientname = res.client.__class__.__name__.lower().split('client')[0]
+            if clientname not in ret:
+                ret.append(clientname)
+        return ret
 
     @property
     def file_num(self):
+        """
+        The number of records returned in all responses.
+        """
         return self._numfile
 
     def _repr_html_(self):
@@ -161,7 +206,7 @@ class UnifiedResponse(Sequence):
             ret = 'Results from {} Provider:</br></br>'.format(len(self))
         else:
             ret = 'Results from {} Providers:</br></br>'.format(len(self))
-        for block in self.responses:
+        for block in self:
             ret += "{} Results from the {}:</br>".format(len(block),
                                                          block.client.__class__.__name__)
             ret += block._repr_html_()
@@ -178,7 +223,7 @@ class UnifiedResponse(Sequence):
             ret = 'Results from {} Provider:\n\n'.format(len(self))
         else:
             ret = 'Results from {} Providers:\n\n'.format(len(self))
-        for block in self.responses:
+        for block in self:
             ret += "{} Results from the {}:\n".format(len(block), block.client.__class__.__name__)
             lines = repr(block).split('\n')
             ret += '\n'.join(lines[1:])
@@ -186,6 +231,34 @@ class UnifiedResponse(Sequence):
 
         return ret
 
+    def show(self, *cols):
+        """
+        Displays response tables with desired columns for the Query.
+
+        Parameters
+        ----------
+        \\*cols : `tuple`
+            Name of columns to be shown.
+
+        Returns
+        -------
+        `list` of `astropy.table.Table`
+            A list of tables showing values for specified columns.
+        """
+        return type(self)(*[i.show(*cols) for i in self._list])
+
+    @property
+    def all_colnames(self):
+        """
+        Returns all the colnames in any of the tables in this response.
+
+        Any column names in this list are valid inputs to :meth:`.UnifiedResponse.show`.
+        """
+        colnames = set(self[0].colnames)
+        for resp in self[1:]:
+            colnames.union(resp.colnames)
+        return sorted(list(colnames))
+
 
 query_walker = attr.AttrWalker()
 """
@@ -279,7 +352,7 @@ class UnifiedDownloaderFactory(BasicRegistrationFactory):
         # This is because the VSO _can_handle_query is very broad because we
         # don't know the full list of supported values we can search for (yet).
         if len(results) > 1:
-            vso_results = list(filter(lambda r: isinstance(r, vso.QueryResponse), results))
+            vso_results = list(filter(lambda r: isinstance(r, vso.VSOQueryResponseTable), results))
             for vres in vso_results:
                 if len(vres) == 0:
                     results.remove(vres)
@@ -289,12 +362,12 @@ class UnifiedDownloaderFactory(BasicRegistrationFactory):
     def fetch(self, *query_results, path=None, max_conn=5, progress=True,
               overwrite=False, downloader=None, **kwargs):
         """
-        Download the records represented by
+        Download the records represented by `~sunpy.net.base_client.QueryResponseTable` or
         `~sunpy.net.fido_factory.UnifiedResponse` objects.
 
         Parameters
         ----------
-        query_results : `sunpy.net.fido_factory.UnifiedResponse`
+        query_results : `sunpy.net.fido_factory.UnifiedResponse` or `~sunpy.net.base_client.QueryResponseTable`
             Container returned by query method, or multiple.
         path : `str`
             The directory to retrieve the files into. Can refer to any fields
@@ -310,7 +383,7 @@ class UnifiedDownloaderFactory(BasicRegistrationFactory):
             Determine how to handle downloading if a file already exists with the
             same name. If `False` the file download will be skipped and the path
             returned to the existing file, if `True` the file will be downloaded
-            and the existing file will be overwritten, if `'unique'` the filename
+            and the existing file will be overwritten, if ``'unique'`` the filename
             will be modified to be unique.
         downloader : `parfive.Downloader`, optional
             The download manager to use. If specified the ``max_conn``,
@@ -331,12 +404,19 @@ class UnifiedDownloaderFactory(BasicRegistrationFactory):
         >>> filepaths = Fido.fetch(filepaths)  # doctest: +SKIP
 
         """
-        if path is not None:
-            exists = list(filter(lambda p: p.exists(), Path(path).resolve().parents))
+        if path is None:
+            path = Path(config.get('downloads', 'download_dir')) / '{file}'
+        elif isinstance(path, (str, os.PathLike)) and '{file}' not in str(path):
+            path = Path(path) / '{file}'
+        else:
+            path = Path(path)
+        path = path.expanduser()
 
-            if not os.access(exists[0], os.W_OK):
-                raise PermissionError('You do not have permission to write'
-                                      f' to the directory {exists[0]}.')
+        # Ensure we have write permissions to the path
+        exists = list(filter(lambda p: p.exists(), Path(path).resolve().parents))
+        if not os.access(exists[0], os.W_OK):
+            raise PermissionError('You do not have permission to write'
+                                  f' to the directory {exists[0]}.')
 
         if "wait" in kwargs:
             raise ValueError("wait is not a valid keyword argument to Fido.fetch.")
@@ -361,17 +441,26 @@ class UnifiedDownloaderFactory(BasicRegistrationFactory):
 
         reslist = []
         for query_result in query_results:
-            for block in query_result.responses:
-                reslist.append(block.client.fetch(block, path=path,
-                                                  downloader=downloader,
-                                                  wait=False, **kwargs))
+            if isinstance(query_result, QueryResponseRow):
+                responses = [query_result.as_table()]
+            elif isinstance(query_result, QueryResponseTable):
+                responses = [query_result]
+            elif isinstance(query_result, UnifiedResponse):
+                responses = query_result
+            else:
+                raise ValueError(f"Query result has an unrecognized type: {type(query_result)} "
+                                 "Allowed types are QueryResponseRow, QueryResponseTable or UnifiedResponse.")
+            for block in responses:
+                result = block.client.fetch(block, path=path,
+                                            downloader=downloader,
+                                            wait=False, **kwargs)
+                if result not in (NotImplemented, None):
+                    reslist.append(result)
 
         results = downloader.download()
         # Combine the results objects from all the clients into one Results
         # object.
         for result in reslist:
-            if result is None:
-                continue
             if not isinstance(result, Results):
                 raise TypeError(
                     "If wait is False a client must return a parfive.Downloader and either None"
@@ -417,14 +506,18 @@ class UnifiedDownloaderFactory(BasicRegistrationFactory):
         results = []
         for client in candidate_widget_types:
             tmpclient = client()
-            results.append(tmpclient.search(*query))
+            kwargs = dict()
+            # Handle the change in response format in the VSO
+            if isinstance(tmpclient, vso.VSOClient):
+                kwargs = dict(response_format="table")
+            results.append(tmpclient.search(*query, **kwargs))
 
         # This method is called by `search` and the results are fed into a
         # UnifiedResponse object.
         return results
 
     def __repr__(self):
-        return object.__repr__(self) + "\n" + str(self)
+        return object.__repr__(self) + "\n" + self._print_clients(visible_entries=15)
 
     def __str__(self):
         """
@@ -436,9 +529,9 @@ class UnifiedDownloaderFactory(BasicRegistrationFactory):
         """
         This enables the "pretty" printing of the Fido Clients with html.
         """
-        return self._print_clients(html=True)
+        return self._print_clients(visible_entries=15, html=True)
 
-    def _print_clients(self, html=False) -> str:
+    def _print_clients(self, html=False, visible_entries=None) -> str:
         width = -1 if html else get_width()
 
         t = Table(names=["Client", "Description"], dtype=["U80", "U120"])
@@ -448,7 +541,8 @@ class UnifiedDownloaderFactory(BasicRegistrationFactory):
         for key in BaseClient._registry.keys():
             t.add_row((key.__name__, dedent(
                 key.__doc__.partition("\n\n")[0].replace("\n    ", " "))))
-        lines.extend(t.pformat_all(show_dtype=False, max_width=width, align="<", html=html))
+        lines.extend(t.pformat_all(max_lines=visible_entries,
+                                   show_dtype=False, max_width=width, align="<", html=html))
         return '\n'.join(lines)
 
 
