@@ -4,7 +4,6 @@ This module provies NOAA Solar Cycle `~sunpy.timeseries.TimeSeries` source.
 from pathlib import Path
 from collections import OrderedDict
 
-import matplotlib.pyplot as plt
 import numpy as np
 import pandas as pd
 from pandas.io.parsers import read_csv
@@ -14,6 +13,7 @@ from astropy.time import Time
 
 from sunpy.time import parse_time
 from sunpy.timeseries.timeseriesbase import GenericTimeSeries
+from sunpy.util.decorators import deprecated
 from sunpy.util.metadata import MetaDict
 from sunpy.visualization import peek_show
 
@@ -30,9 +30,11 @@ class NOAAIndicesTimeSeries(GenericTimeSeries):
 
     * The SWO sunspot number is issued by the NOAA Space Weather Prediction Center (SWPC)
     * The RI sunspot number is the official International Sunspot Number and is
-      issued by the `Solar Influence Data Analysis Center (SDIC) <http://sidc.oma.be>`_ in Brussels, Belgium.
+      issued by the `Solar Influence Data Analysis Center (SDIC)
+      <http://sidc.oma.be>`__ in Brussels, Belgium.
     * The ratio between the SWO and RI indices.
-    * Radio flux at 10.7 cm is produced by `Penticon/Ottawa <https://www.ngdc.noaa.gov/stp/solar/flux.html>`_ and the units are in sfu.
+    * Radio flux at 10.7 cm is produced by
+      `Penticon/Ottawa <https://www.ngdc.noaa.gov/stp/solar/flux.html>`__ and the units are in sfu.
     * The Ap Geomagnetic Index is produced by the United States Air Force (USAF).
 
     .. note::
@@ -74,13 +76,12 @@ class NOAAIndicesTimeSeries(GenericTimeSeries):
         type : {'sunspot SWO', 'sunspot RI', 'sunspot compare', 'radio', 'geo'}, optional
             The type of plot required. Defaults to "sunspot SWO".
         **kwargs : `dict`
-            Additional plot keyword arguments that are handed to `axes.plot` functions
+            Additional plot keyword arguments that are handed to `~matplotlib.axes.Axes.plot`
+            functions.
         """
         # Check we have a timeseries valid for plotting
         self._validate_data_for_plotting()
 
-        figure = plt.figure()
-        axes = plt.gca()
         dataframe = self.to_dataframe()
         if type == 'sunspot SWO':
             axes = dataframe['sunspot SWO'].plot(**kwargs)
@@ -112,7 +113,8 @@ class NOAAIndicesTimeSeries(GenericTimeSeries):
         axes.xaxis.grid(True, 'major')
         axes.legend()
 
-        return figure
+        fig = axes.get_figure()
+        return fig
 
     @classmethod
     def _parse_file(cls, filepath):
@@ -125,6 +127,7 @@ class NOAAIndicesTimeSeries(GenericTimeSeries):
             raise ValueError(f"{Path(filepath).name} does not have a suffix of '.txt' or '.json'")
 
     @staticmethod
+    @deprecated("2.1", "NOAA data products have moved to a new JSON file format.")
     def _parse_txt_file(filepath):
         """
         Parses an NOAA indices text file.
@@ -249,7 +252,7 @@ class NOAAPredictIndicesTimeSeries(GenericTimeSeries):
     # Class attribute used to specify the source class of the TimeSeries.
     _source = 'noaapredictindices'
 
-    @peek_show
+    @ peek_show
     def peek(self, **plot_args):
         """
         Plots predicted NOAA Indices as a function of time. An example is shown
@@ -265,12 +268,11 @@ class NOAAPredictIndicesTimeSeries(GenericTimeSeries):
         Parameters
         ----------
         **plot_args : `dict`
-            Additional plot keyword arguments that are handed to `axes.plot` functions
+            Additional plot keyword arguments that are handed to `~matplotlib.axes.Axes.plot`
+            functions.
         """
         # Check we have a timeseries valid for plotting
         self._validate_data_for_plotting()
-        figure = plt.figure()
-        axes = plt.gca()
         dataframe = self.to_dataframe()
         axes = dataframe['sunspot'].plot(color='b', **plot_args)
         dataframe['sunspot low'].plot(linestyle='--', color='b', **plot_args)
@@ -284,9 +286,10 @@ class NOAAPredictIndicesTimeSeries(GenericTimeSeries):
         axes.xaxis.grid(True, 'major')
         axes.legend()
 
-        return figure
+        fig = axes.get_figure()
+        return fig
 
-    @classmethod
+    @ classmethod
     def _parse_file(cls, filepath):
         suffix = Path(filepath).suffix
         if suffix == '.json':
@@ -296,7 +299,7 @@ class NOAAPredictIndicesTimeSeries(GenericTimeSeries):
         else:
             raise ValueError(f"{Path(filepath).name} does not have a suffix of '.txt' or '.json'")
 
-    @classmethod
+    @ classmethod
     def is_datasource_for(cls, **kwargs):
         """
         Determines if header corresponds to an NOAA predict indices
@@ -305,7 +308,8 @@ class NOAAPredictIndicesTimeSeries(GenericTimeSeries):
         if kwargs.get('source', ''):
             return kwargs.get('source', '').lower().startswith(cls._source)
 
-    @staticmethod
+    @ staticmethod
+    @ deprecated("2.1", "NOAA data products have moved to a new JSON file format.")
     def _parse_txt_file(filepath):
         """
         Parses an NOAA Predict indices text file.
@@ -346,7 +350,7 @@ class NOAAPredictIndicesTimeSeries(GenericTimeSeries):
             # Todo: check units used.
             return data, MetaDict({'comments': header}), units
 
-    @staticmethod
+    @ staticmethod
     def _parse_json_file(filepath):
         """
         Parses an NOAA Predict indices JSON file.
